Contributors
============

- `Tjelvar Olsson <https://github.com/tjelvar-olsson>`_ is the main developer behind the `dtool ecosystem <https://github.com/jic-dtool>`_ and this package leans heavily against the structure of his `dtool-lookup-client <https://github.com/jic-dtool/dtool-lookup-client>`_ and `dtool-lookup-server <https://github.com/jic-dtool/dtool-lookup-server>`_.
- `Lars Pastewka <https://github.com/pastewka>`_ provided the core.LookupClient implementation
